@@ -44,8 +44,8 @@
 
 simple.monitor.function.tests <- function( verbose=T, synopsis=T, 
          fuzz.small=1e-14, fuzz.large=1e-8,
-         server.process = padi.server.process(),
-         cleanup.script = padi.cleanup.script() )
+         server.process = PADIserverProcess(),
+         cleanup.script = PADIcleanupScript() )
 {# Some of the tests here are really for functions defined in dse1 ... dse3
  #   but are not tested there to avoid assuming TSPADI (or Fame) access is
  # available. The main short coming of these tests is that they do not test
@@ -66,14 +66,14 @@ simple.monitor.function.tests <- function( verbose=T, synopsis=T,
 
   if (verbose) cat("simple monitor test 0 ... ")
   # simulate a database server
-  pid <- start.padi.server(server=server,
+  pid <- startPADIserver(server=server,
            dbname=db, 
            server.process=server.process)
-  on.exit(cleanup.padi.server(pid, cleanup.script=cleanup.script))
+  on.exit(cleanupPADIserver(pid, cleanup.script=cleanup.script))
 
   # wait for server to start 
      for (i in 1:30)
-       {if (check.padi.server(server)) break
+       {if (checkPADIserver(server)) break
         Sys.sleep(1)
        }
   ok <- T
